@@ -1,15 +1,16 @@
 """
 Type annotations for secretsmanager service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/)
 
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_secretsmanager import SecretsManagerClient
+    from boto3.session import Session
+    from mypy_boto3_secretsmanager.client import SecretsManagerClient
 
-    client: SecretsManagerClient = boto3.client("secretsmanager")
+    session = Session()
+    client: SecretsManagerClient = session.client("secretsmanager")
     ```
 """
 import sys
@@ -82,8 +83,8 @@ class Exceptions:
 
 class SecretsManagerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/)
     """
 
     meta: ClientMeta
@@ -92,14 +93,17 @@ class SecretsManagerClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         SecretsManagerClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#can_paginate)
         """
 
     def cancel_rotate_secret(self, *, SecretId: str) -> CancelRotateSecretResponseTypeDef:
@@ -107,8 +111,8 @@ class SecretsManagerClient(BaseClient):
         Disables automatic scheduled rotation and cancels the rotation of a secret if
         currently in progress.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#cancel_rotate_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#cancel_rotate_secret)
         """
 
     def create_secret(
@@ -127,16 +131,16 @@ class SecretsManagerClient(BaseClient):
         """
         Creates a new secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#create_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#create_secret)
         """
 
     def delete_resource_policy(self, *, SecretId: str) -> DeleteResourcePolicyResponseTypeDef:
         """
         Deletes the resource-based permission policy attached to the secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#delete_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#delete_resource_policy)
         """
 
     def delete_secret(
@@ -149,16 +153,16 @@ class SecretsManagerClient(BaseClient):
         """
         Deletes an entire secret and all of the versions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#delete_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#delete_secret)
         """
 
     def describe_secret(self, *, SecretId: str) -> DescribeSecretResponseTypeDef:
         """
         Retrieves the details of a secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#describe_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#describe_secret)
         """
 
     def generate_presigned_url(
@@ -171,8 +175,8 @@ class SecretsManagerClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#generate_presigned_url)
         """
 
     def get_random_password(
@@ -190,8 +194,8 @@ class SecretsManagerClient(BaseClient):
         """
         Generates a random password of the specified complexity.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_random_password)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#get_random_password)
         """
 
     def get_resource_policy(self, *, SecretId: str) -> GetResourcePolicyResponseTypeDef:
@@ -199,8 +203,8 @@ class SecretsManagerClient(BaseClient):
         Retrieves the JSON text of the resource-based policy document attached to the
         specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#get_resource_policy)
         """
 
     def get_secret_value(
@@ -210,8 +214,8 @@ class SecretsManagerClient(BaseClient):
         Retrieves the contents of the encrypted fields `SecretString` or `SecretBinary`
         from the specified version of a secret, whichever contains content.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_secret_value)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#get_secret_value)
         """
 
     def list_secret_version_ids(
@@ -225,8 +229,8 @@ class SecretsManagerClient(BaseClient):
         """
         Lists all of the versions attached to the specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#list_secret_version_ids)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#list_secret_version_ids)
         """
 
     def list_secrets(
@@ -241,8 +245,8 @@ class SecretsManagerClient(BaseClient):
         Lists all of the secrets that are stored by Secrets Manager in the Amazon Web
         Services account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#list_secrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#list_secrets)
         """
 
     def put_resource_policy(
@@ -252,8 +256,8 @@ class SecretsManagerClient(BaseClient):
         Attaches the contents of the specified resource-based permission policy to a
         secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#put_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#put_resource_policy)
         """
 
     def put_secret_value(
@@ -268,8 +272,8 @@ class SecretsManagerClient(BaseClient):
         """
         Stores a new encrypted secret value in the specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#put_secret_value)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#put_secret_value)
         """
 
     def remove_regions_from_replication(
@@ -278,8 +282,8 @@ class SecretsManagerClient(BaseClient):
         """
         Remove regions from replication.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.remove_regions_from_replication)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#remove_regions_from_replication)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.remove_regions_from_replication)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#remove_regions_from_replication)
         """
 
     def replicate_secret_to_regions(
@@ -293,8 +297,8 @@ class SecretsManagerClient(BaseClient):
         Converts an existing secret to a multi-Region secret and begins replication the
         secret to a list of new regions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.replicate_secret_to_regions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#replicate_secret_to_regions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.replicate_secret_to_regions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#replicate_secret_to_regions)
         """
 
     def restore_secret(self, *, SecretId: str) -> RestoreSecretResponseTypeDef:
@@ -302,8 +306,8 @@ class SecretsManagerClient(BaseClient):
         Cancels the scheduled deletion of a secret by removing the `DeletedDate` time
         stamp.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#restore_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#restore_secret)
         """
 
     def rotate_secret(
@@ -317,8 +321,8 @@ class SecretsManagerClient(BaseClient):
         """
         Configures and starts the asynchronous process of rotating this secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#rotate_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#rotate_secret)
         """
 
     def stop_replication_to_replica(
@@ -328,8 +332,8 @@ class SecretsManagerClient(BaseClient):
         Removes the secret from replication and promotes the secret to a regional secret
         in the replica Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.stop_replication_to_replica)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#stop_replication_to_replica)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.stop_replication_to_replica)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#stop_replication_to_replica)
         """
 
     def tag_resource(self, *, SecretId: str, Tags: Sequence["TagTypeDef"]) -> None:
@@ -337,16 +341,16 @@ class SecretsManagerClient(BaseClient):
         Attaches one or more tags, each consisting of a key name and a value, to the
         specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#tag_resource)
         """
 
     def untag_resource(self, *, SecretId: str, TagKeys: Sequence[str]) -> None:
         """
         Removes one or more tags from the specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#untag_resource)
         """
 
     def update_secret(
@@ -362,8 +366,8 @@ class SecretsManagerClient(BaseClient):
         """
         Modifies many of the details of the specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#update_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#update_secret)
         """
 
     def update_secret_version_stage(
@@ -377,8 +381,8 @@ class SecretsManagerClient(BaseClient):
         """
         Modifies the staging labels attached to a version of a secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#update_secret_version_stage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#update_secret_version_stage)
         """
 
     def validate_resource_policy(
@@ -388,12 +392,12 @@ class SecretsManagerClient(BaseClient):
         Validates that the resource policy does not grant a wide range of IAM principals
         access to your secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#validate_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#validate_resource_policy)
         """
 
     def get_paginator(self, operation_name: Literal["list_secrets"]) -> ListSecretsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#get_paginator)
         """
