@@ -1,7 +1,7 @@
 """
 Type annotations for secretsmanager service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/literals/)
 
 Usage::
 
@@ -24,8 +24,11 @@ __all__ = (
     "ListSecretsPaginatorName",
     "SortOrderTypeType",
     "StatusTypeType",
+    "SecretsManagerServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -35,6 +38,7 @@ FilterNameStringTypeType = Literal[
 ListSecretsPaginatorName = Literal["list_secrets"]
 SortOrderTypeType = Literal["asc", "desc"]
 StatusTypeType = Literal["Failed", "InProgress", "InSync"]
+SecretsManagerServiceName = Literal["secretsmanager"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -68,6 +72,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -322,4 +327,39 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_secrets"]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
