@@ -1,7 +1,7 @@
 """
 Type annotations for secretsmanager service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/type_defs/)
 
 Usage::
 
@@ -13,9 +13,10 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Sequence, Union
+from typing import IO, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
+from typing_extensions import NotRequired
 
 from .literals import FilterNameStringTypeType, SortOrderTypeType, StatusTypeType
 
@@ -45,6 +46,7 @@ __all__ = (
     "GetSecretValueResponseTypeDef",
     "ListSecretVersionIdsRequestRequestTypeDef",
     "ListSecretVersionIdsResponseTypeDef",
+    "ListSecretsRequestListSecretsPaginateTypeDef",
     "ListSecretsRequestRequestTypeDef",
     "ListSecretsResponseTypeDef",
     "PaginatorConfigTypeDef",
@@ -335,6 +337,16 @@ ListSecretVersionIdsResponseTypeDef = TypedDict(
     },
 )
 
+ListSecretsRequestListSecretsPaginateTypeDef = TypedDict(
+    "ListSecretsRequestListSecretsPaginateTypeDef",
+    {
+        "Filters": Sequence["FilterTypeDef"],
+        "SortOrder": SortOrderTypeType,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListSecretsRequestRequestTypeDef = TypedDict(
     "ListSecretsRequestRequestTypeDef",
     {
@@ -507,7 +519,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
